==> frontengine_dev-0.0.32-py3-none-any.whl: frontengine/utils/multi_language/english.py <==
english_word_dict = {
    # Menubar
    "menu_bar_language": "Language",
    "menu_bar_ui_style": "UI Style",
    # Language Menubar
    "language_menu_bar_english": "English",
    "language_menu_bar_traditional_chinese": "Traditional Chinese",
    "language_menu_bar_please_restart_messagebox": "Please restart",
    # Tab text
    "tab_video_text": "Video",
    "tab_image_text": "Image",
    "tab_web_text": "WEB",
    "tab_gif_text": "GIF AND WEBP",
    "tab_sound_text": "Sound",
    "tab_text_text": "Text",
    "tab_control_center_text": "Control Center",
    "tab_external_ui": "External UI",
    "chat_ui_text": "Chat",
    # Messagebox text
    "paint_gif_message_box_text": "GIF or WEBP error",
    "paint_image_message_box_text": "Image Error",
    "sound_effect_message_box_text": "Sound file error",
    "sound_player_message_box_text": "Sound file error",
    "video_player_message_box_text": "Video error",
    "webview_message_box_text": "Web file error",
    "cant_find_extend_ui_message_box_text": "Can't find UI",
    # Control Center UI
    "control_center_close_all_video": "Close all video",
    "control_center_close_all_image": "Close all image",
    "control_center_close_all_gif": "Close all gif",
    "control_center_close_all_web": "Close all web",
    "control_center_close_all_sound": "Close all sound",
    "control_center_close_all_text": "Close all text",
    "control_center_scene": "Close scene",
    "control_center_clear_log_panel": "Clear Log",
    "chat_scene_close": "Close all chat",
    "control_center_close_all": "Close all",
    # General
    "Opacity": "Opacity",
    "Speed": "Speed",
    "Not Ready": "Not Ready yet.",
    "Ready": "Ready",
    "Show on all screen": "Show on all screen",
    "Volume": "Volume",
    "Font size": "Font size",
    "Play rate": "Play rate",
    "not_prepare": "Not prepare",
    "Show on bottom": "Show on all window bottom",
    "url": "url",
    "text": "text",
    "ui_path": "UI path",
    "position_x": "X - coordinate",
    "position_y": "Y - coordinate",
    "seconds": "sec",
    "close_delay": "Message disappear time sec",
    "country_code": "locale code",
    # GIF setting ui
    "gif_setting_ui_choose_file": "Choose GIF or WEBP file",
    "gif_setting_ui_play": "Start Play GIF or WEBP",
    "gif_setting_message_box": "Please choose a gif or webp",
    # Image setting ui
    "image_setting_choose_file": "Choose Image",
    "image_setting_ui_play": "Start Play Image",
    "image_setting_message_box": "Please choose a Image",
    # Sound player setting ui
    "sound_player_setting_choose_wav_file": "Choose wav file",
    "sound_player_setting_choose_sound_file": "Choose sound file",
    "sound_player_setting_play_wav": "Start Play Wav",
    "sound_player_setting_play_sound": "Start Player",
    "sound_player_setting_message_box_wav": "Please choose a wav",
    "sound_player_setting_message_box_sound": "Please choose a sound file",
    # Text setting ui
    "text_setting_start_draw": "Start draw text on screen",
    # Video setting ui
    "video_setting_choose_file": "Choose video file",
    "video_setting_start_play": "Start Play Video",
    "video_setting_message_box": "Please choose a video file",
    # Web setting ui
    "web_setting_open_url": "Open web with url",
    "web_setting_open_local_file": "Open local file",
    "web_setting_open_enable_input": "Enable input",
    # Scene UI
    "tab_scene_text": "Scene",
    "scene_table_view_type": "Type",
    "scene_file_path": "File path",
    "scene_setting_start_scene_button": "Start Scene",
    "scene_add_image": "Add image to scene",
    "scene_add_gif": "Add gif to scene",
    "scene_add_sound": "Add sound to scene",
    "scene_add_text": "Add text to scene",
    "scene_add_video": "Add video to scene",
    "scene_add_web": "Add web to scene",
    "scene_add_UI": "Add ui to scene",
    "scene_choose_message_box": "Please choose a scene file",
    "scene_choose_output_path_message_box": "Please choose a scene file output path",
    "scene_output": "output scene file",
    "scene_input": "load scene file",
    "tableview_clear": "clear all setting",
    "scene_control_panel": "Scene control panel",
    # Chat scene input
    "chat_scene_input_title": "input chat content",
    "chat_scene_send_chat": "send text",
    # Chat scene
    "chat_scene_start_button": "start chat",
    "chat_scene_new_topic": "new topic",
    "chat_scene_creative": "creative",
    "chat_scene_precise": "precise",
    "chat_scene_balanced": "balanced",
    "chat_gpt_exception": "GPT error, pls retry or new topic",
    # Chat voice input
    "start_chat_voice_input_ui": "Open voice input ui",
    "chat_recognizer_voice_button": "Start listen voice"
}

==> frontengine_dev-0.0.50-py3-none-any.whl: frontengine/utils/multi_language/english.py <==
english_word_dict = {
    # Menubar
    "menu_bar_language": "Language",
    "menu_bar_ui_style": "UI Style",
    # Language Menubar
    "language_menu_bar_english": "English",
    "language_menu_bar_traditional_chinese": "Traditional Chinese",
    "language_menu_bar_please_restart_messagebox": "Please restart",
    # Tab text
    "tab_video_text": "Video",
    "tab_image_text": "Image",
    "tab_web_text": "WEB",
    "tab_gif_text": "GIF AND WEBP",
    "tab_sound_text": "Sound",
    "tab_text_text": "Text",
    "tab_control_center_text": "Control Center",
    "tab_external_ui": "External UI",
    "chat_ui_text": "Chat",
    # Messagebox text
    "paint_gif_message_box_text": "GIF or WEBP error",
    "paint_image_message_box_text": "Image Error",
    "sound_effect_message_box_text": "Sound file error",
    "sound_player_message_box_text": "Sound file error",
    "video_player_message_box_text": "Video error",
    "webview_message_box_text": "Web file error",
    "cant_find_extend_ui_message_box_text": "Can't find UI",
    # Control Center UI
    "control_center_close_all_video": "Close all video",
    "control_center_close_all_image": "Close all image",
    "control_center_close_all_gif": "Close all gif",
    "control_center_close_all_web": "Close all web",
    "control_center_close_all_sound": "Close all sound",
    "control_center_close_all_text": "Close all text",
    "control_center_scene": "Close scene",
    "control_center_clear_log_panel": "Clear Log",
    "chat_scene_close": "Close all chat",
    "control_center_close_all": "Close all",
    # General
    "Opacity": "Opacity",
    "Speed": "Speed",
    "Not Ready": "Not Ready yet.",
    "Ready": "Ready",
    "Show on all screen": "Show on all screen",
    "Volume": "Volume",
    "Font size": "Font size",
    "Play rate": "Play rate",
    "not_prepare": "Not prepare",
    "Show on bottom": "Show on all window bottom",
    "url": "url",
    "text": "text",
    "ui_path": "UI path",
    "position_x": "X - coordinate",
    "position_y": "Y - coordinate",
    "seconds": "sec",
    "close_delay": "Message disappear time sec",
    "country_code": "locale code",
    # GIF setting ui
    "gif_setting_ui_choose_file": "Choose GIF or WEBP file",
    "gif_setting_ui_play": "Start Play GIF or WEBP",
    "gif_setting_message_box": "Please choose a gif or webp",
    # Image setting ui
    "image_setting_choose_file": "Choose Image",
    "image_setting_ui_play": "Start Play Image",
    "image_setting_message_box": "Please choose a Image",
    # Sound player setting ui
    "sound_player_setting_choose_wav_file": "Choose wav file",
    "sound_player_setting_choose_sound_file": "Choose sound file",
    "sound_player_setting_play_wav": "Start Play Wav",
    "sound_player_setting_play_sound": "Start Player",
    "sound_player_setting_message_box_wav": "Please choose a wav",
    "sound_player_setting_message_box_sound": "Please choose a sound file",
    # Text setting ui
    "text_setting_start_draw": "Start draw text on screen",
    # Video setting ui
    "video_setting_choose_file": "Choose video file",
    "video_setting_start_play": "Start Play Video",
    "video_setting_message_box": "Please choose a video file",
    # Web setting ui
    "web_setting_open_url": "Open web with url",
    "web_setting_open_local_file": "Open local file",
    "web_setting_open_enable_input": "Enable input",
    # Scene UI
    "tab_scene_text": "Scene",
    "scene_table_view_type": "Type",
    "scene_file_path": "File path",
    "scene_setting_start_scene_button": "Start Scene",
    "scene_add_image": "Add image to scene",
    "scene_add_gif": "Add gif to scene",
    "scene_add_sound": "Add sound to scene",
    "scene_add_text": "Add text to scene",
    "scene_add_video": "Add video to scene",
    "scene_add_web": "Add web to scene",
    "scene_add_UI": "Add ui to scene",
    "scene_choose_message_box": "Please choose a scene file",
    "scene_choose_output_path_message_box": "Please choose a scene file output path",
    "scene_output": "output scene file",
    "scene_input": "load scene file",
    "tableview_clear": "clear all setting",
    "scene_control_panel": "Scene control panel",
    # Chat scene input
    "chat_scene_input_title": "input chat content",
    "chat_scene_send_chat": "send text",
    # Chat scene
    "chat_scene_start_button": "start chat",
    "chat_scene_new_topic": "new topic",
    "chat_scene_creative": "creative",
    "chat_scene_precise": "precise",
    "chat_scene_balanced": "balanced",
    "chat_gpt_exception": "GPT error, pls retry or new topic",
    # Chat voice input
    "start_chat_voice_input_ui": "Open voice input ui",
    "chat_recognizer_voice_button": "Start listen voice",
    # Image Generation
    "image_generation_tab": "Image generation",
    "start_generate_image": "Star generate",
    "input_error": "Please input something",
    "save_generation_image": "Save Image",
}
